==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/globals/impl/GlobalElementInSystemSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.globals.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.SystemModelSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.SystemModelSetImpl;
import io.ciera.tool.sql.ooaofooa.globals.GlobalElementInSystem;
import io.ciera.tool.sql.ooaofooa.globals.GlobalElementInSystemSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;

import java.util.Arrays;
import java.util.List;


public class GlobalElementInSystemSetImpl extends InstanceSet<GlobalElementInSystemSet,GlobalElementInSystem> implements GlobalElementInSystemSet {

    // attributes
    @Override
    public void setSys_ID( UniqueId ref_Sys_ID ) throws XtumlException {
        for ( GlobalElementInSystem globalelementinsystem : this ) globalelementinsystem.setSys_ID( ref_Sys_ID );
    }
    @Override
    public void setElement_ID( UniqueId ref_Element_ID ) throws XtumlException {
        for ( GlobalElementInSystem globalelementinsystem : this ) globalelementinsystem.setElement_ID( ref_Element_ID );
    }


    // selections
    @Override
    public PackageableElementSet R9100_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( GlobalElementInSystem globalelementinsystem : this ) packageableelementset.add( globalelementinsystem.R9100_PackageableElement() );
        return packageableelementset;
    }
    @Override
    public SystemModelSet R9100_SystemModel() throws XtumlException {
        SystemModelSet systemmodelset = new SystemModelSetImpl();
        for ( GlobalElementInSystem globalelementinsystem : this ) systemmodelset.add( globalelementinsystem.R9100_SystemModel() );
        return systemmodelset;
    }


    @Override
    public GlobalElementInSystem nullElement() {
        return GlobalElementInSystemImpl.EMPTY_GLOBALELEMENTINSYSTEM;
    }

    @Override
    public GlobalElementInSystemSet emptySet() {
      return new GlobalElementInSystemSetImpl();
    }

    @Override
    public GlobalElementInSystemSet value() {
        return this;
    }

    @Override
    public List<GlobalElementInSystem> elements() {
        return Arrays.asList(toArray(new GlobalElementInSystem[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/globals/impl/GlobalElementInSystemSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.globals.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.SystemModelSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.SystemModelSetImpl;
import io.ciera.tool.sql.ooaofooa.globals.GlobalElementInSystem;
import io.ciera.tool.sql.ooaofooa.globals.GlobalElementInSystemSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class GlobalElementInSystemSetImpl extends InstanceSet<GlobalElementInSystemSet,GlobalElementInSystem> implements GlobalElementInSystemSet {

    public GlobalElementInSystemSetImpl() {
    }

    public GlobalElementInSystemSetImpl(Comparator<? super GlobalElementInSystem> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setSys_ID( UniqueId ref_Sys_ID ) throws XtumlException {
        for ( GlobalElementInSystem globalelementinsystem : this ) globalelementinsystem.setSys_ID( ref_Sys_ID );
    }
    @Override
    public void setElement_ID( UniqueId ref_Element_ID ) throws XtumlException {
        for ( GlobalElementInSystem globalelementinsystem : this ) globalelementinsystem.setElement_ID( ref_Element_ID );
    }


    // selections
    @Override
    public PackageableElementSet R9100_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( GlobalElementInSystem globalelementinsystem : this ) packageableelementset.add( globalelementinsystem.R9100_PackageableElement() );
        return packageableelementset;
    }
    @Override
    public SystemModelSet R9100_SystemModel() throws XtumlException {
        SystemModelSet systemmodelset = new SystemModelSetImpl();
        for ( GlobalElementInSystem globalelementinsystem : this ) systemmodelset.add( globalelementinsystem.R9100_SystemModel() );
        return systemmodelset;
    }


    @Override
    public GlobalElementInSystem nullElement() {
        return GlobalElementInSystemImpl.EMPTY_GLOBALELEMENTINSYSTEM;
    }

    @Override
    public GlobalElementInSystemSet emptySet() {
      return new GlobalElementInSystemSetImpl();
    }

    @Override
    public GlobalElementInSystemSet emptySet(Comparator<? super GlobalElementInSystem> comp) {
      return new GlobalElementInSystemSetImpl(comp);
    }

    @Override
    public GlobalElementInSystemSet value() {
        return this;
    }

    @Override
    public List<GlobalElementInSystem> elements() {
        return Arrays.asList(toArray(new GlobalElementInSystem[0]));
    }

}
